@@ -2,6 +2,7 @@ from pathlib import Path
 
 from django.contrib.auth.hashers import PBKDF2PasswordHasher
 
+from tests.common.settings import IDP_OIDC_PRIVATE_KEY  # noqa
 from tests.common.settings import INSTALLED_SOCIALACCOUNT_APPS
 
 
@@ -74,6 +75,7 @@ INSTALLED_APPS = (
     "allauth.mfa",
     "allauth.usersessions",
     "allauth.headless",
+    "allauth.idp.oidc",
 ) + INSTALLED_SOCIALACCOUNT_APPS
 
 AUTHENTICATION_BACKENDS = (
